thetaphi                Tue Jul 15 13:30:33 2003 EDT

  Modified files:              
    /php-src/sapi/nsapi nsapi.c 
  Log:
  Make virtual() an alias for nsapi_virtual() -- better for docs/naming in future
  
Index: php-src/sapi/nsapi/nsapi.c
diff -u php-src/sapi/nsapi/nsapi.c:1.49 php-src/sapi/nsapi/nsapi.c:1.50
--- php-src/sapi/nsapi/nsapi.c:1.49     Wed Jul  2 18:39:37 2003
+++ php-src/sapi/nsapi/nsapi.c  Tue Jul 15 13:30:33 2003
@@ -17,7 +17,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: nsapi.c,v 1.49 2003/07/02 22:39:37 thetaphi Exp $ */
+/* $Id: nsapi.c,v 1.50 2003/07/15 17:30:33 thetaphi Exp $ */
 
 /*
  * PHP includes
@@ -160,7 +160,7 @@
 PHP_RSHUTDOWN_FUNCTION(nsapi);
 PHP_MINFO_FUNCTION(nsapi);
 
-PHP_FUNCTION(virtual);
+PHP_FUNCTION(nsapi_virtual);
 PHP_FUNCTION(nsapi_request_headers);
 PHP_FUNCTION(nsapi_response_headers);
 
@@ -177,7 +177,8 @@
  * Every user visible function must have an entry in nsapi_functions[].
  */
 function_entry nsapi_functions[] = {
-       PHP_FE(virtual, NULL)                                                          
                                 /* Make subrequest */
+       PHP_FE(nsapi_virtual,   NULL)                                                  
                         /* Make subrequest */
+       PHP_FALIAS(virtual, nsapi_virtual, NULL)                                       
                 /* compatibility */
        PHP_FE(nsapi_request_headers, NULL)                                            
                         /* get request headers */
        PHP_FALIAS(getallheaders, nsapi_request_headers, NULL)                         
 /* compatibility */
        PHP_FALIAS(apache_request_headers, nsapi_request_headers, NULL)         /* 
compatibility */
@@ -198,7 +199,7 @@
        NULL,
        NULL,
        PHP_MINFO(nsapi),
-       "$Revision: 1.49 $",
+       "$Revision: 1.50 $",
        STANDARD_MODULE_PROPERTIES
 };
 /* }}} */
@@ -301,7 +302,7 @@
        php_info_print_table_start();
        php_info_print_table_row(2, "NSAPI Module Version", 
nsapi_module_entry.version);
        php_info_print_table_row(2, "Server Software", system_version());
-       php_info_print_table_row(2, "Sub-requests with virtual()",
+       php_info_print_table_row(2, "Sub-requests with nsapi_virtual()",
         (nsapi_servact_service)?((zend_ini_long("zlib.output_compression", 
sizeof("zlib.output_compression"), 0))?"not supported with 
zlib.output_compression":"enabled"):"not supported on this platform" );
        php_info_print_table_end();
 
@@ -309,14 +310,14 @@
 }
 /* }}} */
 
-/* {{{ proto bool virtual(string filename)
+/* {{{ proto bool nsapi_virtual(string uri)
    Perform an NSAPI sub-request */
 /* This function is equivalent to <!--#include virtual...-->
  * in SSI. It does an NSAPI sub-request. It is useful
  * for including CGI scripts or .shtml files, or anything else
  * that you'd parse through webserver.
  */
-PHP_FUNCTION(virtual)
+PHP_FUNCTION(nsapi_virtual)
 {
        pval **uri;
        int rv;
@@ -822,11 +823,11 @@
 
        TSRMLS_FETCH();
 
        /* check if this uri was included in an other PHP script with virtual()
           by looking for a request context in the current thread */
        if (SG(server_context)) {
                /* send 500 internal server error */
-               log_error(LOG_WARN, "php5_execute", sn, rq, "Cannot make nesting PHP 
requests with virtual()");
+               log_error(LOG_WARN, "php5_execute", sn, rq, "Cannot make nesting PHP 
requests with nsapi_virtual()");
                protocol_status(sn, rq, 500, NULL);
                return REQ_ABORTED;
@@ -822,11 +823,11 @@
        TSRMLS_FETCH();
 
-       /* check if this uri was included in an other PHP script with virtual()
+       /* check if this uri was included in an other PHP script with nsapi_virtual()
           by looking for a request context in the current thread */
        if (SG(server_context)) {
        }



-- 
PHP CVS Mailing List (http://www.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php

Reply via email to